@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::Node;
 
-our $VERSION = '0.82';
+our $VERSION = '0.83';
 
 use YAML::Tag;
 require YAML::Mo;
@@ -19,6 +19,9 @@ sub ynode {
     elsif (ref($_[0]) eq 'ARRAY') {
 	$self = tied(@{$_[0]});
     }
+    elsif (ref(\$_[0]) eq 'GLOB') {
+	$self = tied(*{$_[0]});
+    }
     else {
 	$self = tied($_[0]);
     }
